@@ -4,7 +4,11 @@ import json
 import locale
 import os
 import sys
-from collections import OrderedDict
+
+try:
+    from collections import OrderedDict
+except ImportError:
+    from ordereddict import OrderedDict
 
 from django.conf import settings
 from django.core import mail
